/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLUListElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLUListElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLUListElement.h"
#include "gdom/PrivateIntGdomHTMLUListElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLUListElement::GDOMHTMLUListElement(PassRefPtr<WebCore::HTMLUListElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLUListElement.h"
#include <gdom/GdomHTMLUListElement.h>
#include <gdom/PrivateGdomHTMLUListElement.h>
#include <gdom/PrivateIntGdomHTMLUListElement.h>
#include <gdom/GdomHTMLUListElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLUListElement, gdom_htmlu_list_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLUListElementPrivate {
    class WebCore::HTMLUListElement *item;
};

#define GDOM_HTMLU_LIST_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTMLU_LIST_ELEMENT, GdomHTMLUListElementPrivate))
*/
G_END_DECLS
WebCore::HTMLUListElement *
gdom_htmlu_list_element_get_private(GdomHTMLUListElement *request)
{
    GDOMHTMLUListElement *res;
    res = static_cast<GDOMHTMLUListElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLUListElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_COMPACT,
    PROP_TYPE,
};


static void gdom_htmlu_list_element_finalize(GObject* object)
{
    /*GdomHTMLUListElement* request = GDOM_HTMLU_LIST_ELEMENT(object);*/
    /*GdomHTMLUListElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_htmlu_list_element_parent_class)->finalize(object);
}

static void gdom_htmlu_list_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLUListElement *self = GDOM_HTMLU_LIST_ELEMENT(object);
    WebCore::HTMLUListElement * gself = (gdom_htmlu_list_element_get_private(self));
    switch (prop_id) {
     case PROP_COMPACT:
    {
         gself->setCompact((g_value_get_boolean (value)) );
         break;
    }
     case PROP_TYPE:
    {
         gself->setType(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_htmlu_list_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLUListElement *self = GDOM_HTMLU_LIST_ELEMENT(object);
    WebCore::HTMLUListElement * gself = (gdom_htmlu_list_element_get_private(self));
    switch (prop_id) {
    case PROP_COMPACT:
    {
         g_value_set_boolean (value, gself->compact());
         break;
    }
    case PROP_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->type()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_htmlu_list_element_class_init(GdomHTMLUListElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_htmlu_list_element_finalize;
    g_klass->set_property = gdom_htmlu_list_element__set_property_fn;
    g_klass->get_property = gdom_htmlu_list_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_COMPACT,
            g_param_spec_boolean ("compact", /* name */
                "htmlu_list_element_compact", /* short description */
                "read-write  gboolean HTMLUListElement.compact", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TYPE,
            g_param_spec_string ("type", /* name */
                "htmlu_list_element_type", /* short description */
                "read-write  gchar * HTMLUListElement.type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLUListElementPrivate));*/
}

static void gdom_htmlu_list_element_init(GdomHTMLUListElement* request)
{
    /*GdomHTMLUListElementPrivate* priv = GDOM_HTMLU_LIST_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

